@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright Kevin Deldycke <kevin@deldycke.com> and contributors.
 # All Rights Reserved.
 #
@@ -37,8 +35,8 @@ class DedupMail:
     """Message with deduplication-specific properties and utilities.
 
     Adds all data-cleaning primitives and heuristics to Python's standard
-    library messages from: https://github.com/python/cpython/blob
-    /e799aa8b92c195735f379940acd9925961ad04ec/Lib/mailbox.py#L1489
+    library messages from:
+    https://github.com/python/cpython/blob/e799aa8b92c195735f379940acd9925961ad04ec/Lib/mailbox.py#L1489
 
     This class should not be used directly but composed with
     ``mailbox.Message`` sub-classes.
@@ -77,7 +75,7 @@ class DedupMail:
         self.conf = None
 
     def add_box_metadata(self, box, mail_id):
-        """Post-instanciation utility to attach to mail some metadata derived from its
+        """Post-instantiation utility to attach to mail some metadata derived from its
         parent box.
 
         Called right after the ``__init__()`` constructor.
@@ -202,7 +200,8 @@ class DedupMail:
 
     @cachedproperty
     def canonical_headers(self):
-        """Returns the full list of all canonical headers names and values in preparation for hashing."""
+        """Returns the full list of all canonical headers names and values in
+        preparation for hashing."""
         canonical_headers = []
 
         for header_id in self.conf.hash_headers:
@@ -229,10 +228,10 @@ class DedupMail:
         """Renders into a table and in the same order, headers names and values
         used to produce mail's hash.
 
-        Returns a string ready to be printing to user or for debugging.
+        Returns a string ready for printing to the user or for debugging.
         """
         table = [["Header ID", "Header value"]] + list(self.canonical_headers)
-        return tabulate(table, tablefmt="fancy_grid", headers="firstrow")
+        return "\n" + tabulate(table, tablefmt="fancy_grid", headers="firstrow")
 
     @cachedproperty
     def serialized_headers(self):
